FermiPy
=======

Fermi Python Analysis Framework

* Documentation: http://fermipy.readthedocs.org/
* Installation: http://fermipy.readthedocs.org/en/latest/install.html

License
-------
This project is licensed under a 3-clause BSD style license - see the
``licenses/LICENSE.rst`` file.



